@@ -29,9 +29,9 @@ OF_DIRECT_MEMBERS
 #ifdef __cplusplus
 extern "C" {
 #endif
-extern bool _OFIRIIsIPv6Host(OFString *host) OF_VISIBILITY_HIDDEN;
+extern bool _OFIRIIsIPv6Host(OFString *host) OF_VISIBILITY_INTERNAL;
 extern void _OFIRIVerifyIsEscaped(OFString *, OFCharacterSet *, bool)
-    OF_VISIBILITY_HIDDEN;
+    OF_VISIBILITY_INTERNAL;
 #ifdef __cplusplus
 }
 #endif
