@@ -24,6 +24,9 @@
 
 #import "OFMutableArray.h"
 #import "OFConcreteMutableArray.h"
+#import "OFData.h"
+#import "OFIndexSet.h"
+#import "OFIndexSet+Private.h"
 
 #import "OFEnumerationMutationException.h"
 #import "OFInvalidArgumentException.h"
@@ -158,7 +161,8 @@ OF_SINGLETON_METHODS
 
 + (instancetype)arrayWithCapacity: (size_t)capacity
 {
-	return [[[self alloc] initWithCapacity: capacity] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithCapacity: capacity]);
 }
 
 - (instancetype)init
@@ -214,11 +218,64 @@ OF_SINGLETON_METHODS
 		[self insertObject: object atIndex: idx + i++];
 }
 
+- (void)insertObjects: (OFArray *)array atIndexes: (OFIndexSet *)indexes
+{
+	void *pool = objc_autoreleasePoolPush();
+	const OFRange *ranges = indexes.of_ranges.items;
+	size_t count = indexes.of_ranges.count;
+	size_t arrayIndex = 0;
+
+	for (size_t i = 0; i < count; i++) {
+		void *pool2 = objc_autoreleasePoolPush();
+		OFArray *objects = [array objectsInRange:
+		    OFMakeRange(arrayIndex, ranges[i].length)];
+
+		[self insertObjectsFromArray: objects
+				     atIndex: ranges[i].location];
+
+		arrayIndex += ranges[i].length;
+
+		objc_autoreleasePoolPop(pool2);
+	}
+
+	objc_autoreleasePoolPop(pool);
+}
+
 - (void)replaceObjectAtIndex: (size_t)idx withObject: (id)object
 {
 	OF_UNRECOGNIZED_SELECTOR
 }
 
+- (void)replaceObjectsInRange: (OFRange)range
+	 withObjectsFromArray: (OFArray *)objects
+{
+	[self removeObjectsInRange: range];
+	[self insertObjectsFromArray: objects atIndex: range.location];
+}
+
+- (void)replaceObjectsAtIndexes: (OFIndexSet *)indexes
+		    withObjects: (OFArray *)objects
+{
+	void *pool = objc_autoreleasePoolPush();
+	const OFRange *ranges = indexes.of_ranges.items;
+	size_t rangesCount = indexes.of_ranges.count;
+	size_t objectsIndex = 0;
+
+	if (objects.count != indexes.count)
+		@throw [OFOutOfRangeException exception];
+
+	for (size_t i = 0; i < rangesCount; i++) {
+		for (size_t j = ranges[i].location; j < OFEndOfRange(ranges[i]);
+		    j++) {
+			id object = [objects objectAtIndex: objectsIndex++];
+
+			[self replaceObjectAtIndex: j withObject: object];
+		}
+	}
+
+	objc_autoreleasePoolPop(pool);
+}
+
 - (void)setObject: (id)object atIndexedSubscript: (size_t)idx
 {
 	[self replaceObjectAtIndex: idx withObject: object];
@@ -303,6 +360,23 @@ OF_SINGLETON_METHODS
 		[self removeObjectAtIndex: range.location];
 }
 
+- (void)removeObjectsAtIndexes: (OFIndexSet *)indexes
+{
+	void *pool = objc_autoreleasePoolPush();
+	const OFRange *ranges = indexes.of_ranges.items;
+	size_t count = indexes.of_ranges.count;
+
+	if (count == 0) {
+		objc_autoreleasePoolPop(pool);
+		return;
+	}
+
+	for (size_t i = count; i > 0; i--)
+		[self removeObjectsInRange: ranges[i - 1]];
+
+	objc_autoreleasePoolPop(pool);
+}
+
 - (void)removeLastObject
 {
 	size_t count = self.count;
@@ -336,12 +410,12 @@ OF_SINGLETON_METHODS
 	id object1 = [self objectAtIndex: idx1];
 	id object2 = [self objectAtIndex: idx2];
 
-	[object1 retain];
+	objc_retain(object1);
 	@try {
 		[self replaceObjectAtIndex: idx1 withObject: object2];
 		[self replaceObjectAtIndex: idx2 withObject: object1];
 	} @finally {
-		[object1 release];
+		objc_release(object1);
 	}
 }
 
