@@ -187,11 +187,11 @@ static OFDictionary<OFString *, NSString *> *directionalPadsMap;
 		[directionalPads setObject: directionalPad forKey: @"D-Pad"];
 
 		[directionalPads makeImmutable];
-		_directionalPads = [directionalPads retain];
+		_directionalPads = objc_retain(directionalPads);
 
 		objc_autoreleasePoolPop(pool);
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -200,8 +200,8 @@ static OFDictionary<OFString *, NSString *> *directionalPadsMap;
 
 - (void)dealloc
 {
-	[_buttons release];
-	[_directionalPads release];
+	objc_release(_buttons);
+	objc_release(_directionalPads);
 
 	[super dealloc];
 }
