@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -23,10 +23,12 @@
 
 OF_ASSUME_NONNULL_BEGIN
 
+OF_SUBCLASSING_RESTRICTED
 @interface OFGnuTLSTLSStream: OFTLSStream <OFStreamDelegate>
 {
-	bool _initialized, _handshakeDone;
+	bool _server, _handshakeDone;
 	gnutls_session_t _session;
+	gnutls_certificate_credentials_t _credentials;
 	OFString *_host;
 }
 @end
