@@ -50,7 +50,7 @@ static OFString *const cArray[] = {
 
 - (void)dealloc
 {
-	[_array release];
+	objc_release(_array);
 
 	[super dealloc];
 }
@@ -113,12 +113,12 @@ static OFString *const cArray[] = {
 
 - (void)testCopy
 {
-	OTAssertEqualObjects([[_array copy] autorelease], _array);
+	OTAssertEqualObjects(objc_autorelease([_array copy]), _array);
 }
 
 - (void)testMutableCopy
 {
-	OTAssertEqualObjects([[_array mutableCopy] autorelease], _array);
+	OTAssertEqualObjects(objc_autorelease([_array mutableCopy]), _array);
 }
 
 - (void)testObjectAtIndex
@@ -161,12 +161,37 @@ static OFString *const cArray[] = {
 	    OFNotFound);
 }
 
-- (void)objectsInRange
+- (void)testObjectsInRange
 {
+	OTAssertEqualObjects([_array objectsInRange: OFMakeRange(0, 1)],
+	    [self.arrayClass arrayWithObject: cArray[0]]);
+
 	OTAssertEqualObjects([_array objectsInRange: OFMakeRange(1, 2)],
 	    ([self.arrayClass arrayWithObjects: cArray[1], cArray[2], nil]));
 }
 
+- (void)testObjectsInRangeThrowsOnOutOfRangeRange
+{
+	OTAssertThrowsSpecific([_array objectsInRange: OFMakeRange(3, 1)],
+	    OFOutOfRangeException);
+}
+
+- (void)testObjectsAtIndexes
+{
+	OFMutableIndexSet *indexes = [OFMutableIndexSet indexSetWithIndex: 0];
+	[indexes addIndex: 2];
+
+	OTAssertEqualObjects([_array objectsAtIndexes: indexes],
+	    ([self.arrayClass arrayWithObjects: cArray[0], cArray[2], nil]));
+}
+
+- (void)testObjectsAtIndexesThrowsOnOutOfRangeIndex
+{
+	OTAssertThrowsSpecific(
+	    [_array objectsAtIndexes: [OFIndexSet indexSetWithIndex: 3]],
+	    OFOutOfRangeException);
+}
+
 - (void)testEnumerator
 {
 	OFEnumerator *enumerator = [_array objectEnumerator];
@@ -309,7 +334,7 @@ static OFString *const cArray[] = {
 		_array = [[OFArray alloc] initWithObjects: objects
 						    count: count];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -318,7 +343,7 @@ static OFString *const cArray[] = {
 
 - (void)dealloc
 {
-	[_array release];
+	objc_release(_array);
 
 	[super dealloc];
 }
